@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2020 by Dominique Dumont.
+# This software is Copyright (c) 2008-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -17,7 +17,7 @@ return [
       {
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn' => 'Unknown parameter'
+        'warn' => 'Unexpected systemd parameter. Please contact cme author to update systemd model.'
       }
     ],
     'class_description' => "A unit file is a plain text ini-style file that encodes information about a service, a
@@ -105,7 +105,7 @@ Unit files may specify aliases through the C<Alias> directive in the [Install]
 section. When the unit is enabled, symlinks will be created for those names, and removed when the unit is
 disabled. For example, C<reboot.target> specifies
 C<Alias=ctrl-alt-del.target>, so when enabled, the symlink
-C</etc/systemd/systemd/ctrl-alt-del.service> pointing to the
+C</etc/systemd/system/ctrl-alt-del.service> pointing to the
 C<reboot.target> file will be created, and when
 CtrlAltDel is invoked,
 systemd will look for the C<ctrl-alt-del.service> and execute
@@ -126,13 +126,15 @@ the enable or preset commands of
 L<systemctl(1)>.
 
 Along with a unit file C<foo.service>, a \"drop-in\" directory
-C<foo.service.d/> may exist. All files with the suffix C<.conf> from this
-directory will be parsed after the unit file itself is parsed. This is useful to alter or add configuration
-settings for a unit, without having to modify unit files. Drop-in files must contain appropriate section
-headers. For instantiated units, this logic will first look for the instance C<.d/> subdirectory
-(e.g. C<foo\@bar.service.d/>) and read its C<.conf> files, followed by the template
-C<.d/> subdirectory (e.g. C<foo\@.service.d/>) and the C<.conf>
-files there. Moreover for units names containing dashes (C<->), the set of directories generated by
+C<foo.service.d/> may exist. All files with the suffix
+C<.conf> from this directory will be merged in the alphanumeric order and parsed
+after the main unit file itself has been parsed. This is useful to alter or add configuration
+settings for a unit, without having to modify unit files. Each drop-in file must contain appropriate
+section headers. For instantiated units, this logic will first look for the instance
+C<.d/> subdirectory (e.g. C<foo\@bar.service.d/>) and read its
+C<.conf> files, followed by the template C<.d/> subdirectory (e.g.
+C<foo\@.service.d/>) and the C<.conf> files there. Moreover for unit
+names containing dashes (C<->), the set of directories generated by repeatedly
 truncating the unit name after all dashes is searched too. Specifically, for a unit name
 C<foo-bar-baz.service> not only the regular drop-in directory
 C<foo-bar-baz.service.d/> is searched but also both C<foo-bar-.service.d/> and
@@ -165,10 +167,12 @@ Units also support a top-level drop-in with C<type.d/>,
 where type may be e.g. C<service> or C<socket>,
 that allows altering or adding to the settings of all corresponding unit files on the system.
 The formatting and precedence of applying drop-in configurations follow what is defined above.
-Configurations in C<type.d/> have the lowest precedence
-compared to settings in the name specific override directories. So the contents of
-C<foo-.service.d/10-override.conf> would override
-C<service.d/10-override.conf>.
+Files in C<type.d/> have lower precedence compared
+to files in name-specific override directories. The usual rules apply: multiple drop-in files
+with different names are applied in lexicographic order, regardless of which of the directories
+they reside in, so a file in C<type.d/> applies
+to a unit only if there are no drop-ins or masks with that name in directories with higher
+precedence. See Examples.
 
 Note that while systemd offers a flexible dependency system
 between units it is recommended to use this functionality only
@@ -225,28 +229,31 @@ L<systemctl(1)>
 for its usage and precaution.
 
 
-Unit files may also include a number of C<Condition\x{2026}=> and
-C<Assert\x{2026}=> settings. Before the unit is started, systemd will verify
-that the specified conditions are true. If not, the starting of the unit will be (mostly silently)
-skipped. Failing conditions will not result in the unit being moved into the C<failed>
-state. The conditions are checked at the time the queued start job is to be executed. The ordering
-dependencies are still respected, so other units are still pulled in and ordered as if this unit was
-successfully activated. Use condition expressions in order to skip units that do not apply to the local
-system, for example because the kernel or runtime environment doesn't require their functionality.
+Unit files may also include a number of C<Condition\x{2026}=> and C<Assert\x{2026}=> settings. Before the unit is started, systemd will verify that the
+specified conditions and asserts are true. If not, the starting of the unit will be (mostly silently)
+skipped (in case of conditions), or aborted with an error message (in case of asserts). Failing
+conditions or asserts will not result in the unit being moved into the C<failed>
+state. The conditions and asserts are checked at the time the queued start job is to be executed. The
+ordering dependencies are still respected, so other units are still pulled in and ordered as if this
+unit was successfully activated, and the conditions and asserts are executed the precise moment the
+unit would normally start and thus can validate system state after the units ordered before completed
+initialization. Use condition expressions for skipping units that do not apply to the local system, for
+example because the kernel or runtime environment doesn't require their functionality.
 
 
 If multiple conditions are specified, the unit will be executed if all of them apply (i.e. a
 logical AND is applied). Condition checks can use a pipe symbol (C<|>) after the equals
-sign (C<Condition\x{2026}=|\x{2026}>), which causes the condition becomes a triggering condition. If
-at least one triggering condition is defined for a unit, then the unit will be executed if at least one
-of the triggering conditions apply and all of the non-triggering conditions. If you prefix an argument
-with the pipe symbol and an exclamation mark, the pipe symbol must be passed first, the exclamation
-second. If any of these options is assigned the empty string, the list of conditions is reset
-completely, all previous condition settings (of any kind) will have no effect.
+sign (C<Condition\x{2026}=|\x{2026}>), which causes the condition to become a
+triggering condition. If at least one triggering condition is defined for a unit,
+then the unit will be started if at least one of the triggering conditions of the unit applies and all
+of the regular (i.e. non-triggering) conditions apply. If you prefix an argument with the pipe symbol
+and an exclamation mark, the pipe symbol must be passed first, the exclamation second. If any of these
+options is assigned the empty string, the list of conditions is reset completely, all previous
+condition settings (of any kind) will have no effect.
 
 The C<AssertArchitecture>, C<AssertVirtualization>, \x{2026} options
-provide a similar mechanism that causes the job to fail (instead of being skipped). The failed check is
-logged. Units with failed conditions are considered to be in a clean state and will be garbage
+are similar to conditions but cause the start job to fail (instead of being skipped). The failed check
+is logged. Units with failed conditions are considered to be in a clean state and will be garbage
 collected if they are not referenced. This means that when queried, the condition failure may or may
 not show up in the state of the unit.
 
@@ -270,20 +277,19 @@ by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-
     'element' => [
       'Description',
       {
-        'description' => 'A human readable name for the unit. This is used by
-systemd (and other UIs) as the label for the unit, so this string should
-identify the unit rather than describe it, despite the name. C<Apache2 Web
-Server> is a good example. Bad examples are C<high-performance light-weight
-HTTP server> (too generic) or C<Apache2> (too specific and
-meaningless for people who do not know Apache). systemd will use this
-string as a noun in status messages (C<Starting
+        'description' => 'A short human readable title of the unit. This may be used by
+systemd (and other UIs) as a user-visible label for the unit, so this string
+should identify the unit rather than describe it, despite the name. This string also shouldn\'t just
+repeat the unit name. C<Apache2 Web Server> is a good example. Bad examples are
+C<high-performance light-weight HTTP server> (too generic) or
+C<Apache2> (meaningless for people who do not know Apache, duplicates the unit
+name). systemd may use this string as a noun in status messages (C<Starting
 description...>, C<Started
 description.>, C<Reached target
 description.>, C<Failed to start
-description.>), so it should be capitalized, and should
-not be a full sentence or a phrase with a continuous verb. Bad examples include
-C<exiting the container> or C<updating the database once per
-day.>.',
+description.>), so it should be capitalized, and should not be a
+full sentence, or a phrase with a continuous verb. Bad examples include C<exiting the
+container> or C<updating the database once per day.>.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
@@ -316,11 +322,11 @@ effect.',
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
-        'description' => 'Configures requirement dependencies on other units. This option may be specified more
-than once or multiple space-separated units may be specified in one option in which case dependencies
-for all listed names will be created. Dependencies of this type may also be configured outside of the
-unit configuration file by adding a symlink to a C<.wants/> directory accompanying
-the unit file. For details, see above.
+        'description' => 'Configures (weak) requirement dependencies on other units. This option may be
+specified more than once or multiple space-separated units may be specified in one option in which
+case dependencies for all listed names will be created. Dependencies of this type may also be
+configured outside of the unit configuration file by adding a symlink to a
+C<.wants/> directory accompanying the unit file. For details, see above.
 
 Units listed in this option will be started if the configuring unit is. However, if the listed
 units fail to start or cannot be added to the transaction, this has no impact on the validity of the
@@ -342,7 +348,7 @@ activated.',
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
-        'description' => "Similar to C<Wants>, but declares a stronger
+        'description' => "Similar to C<Wants>, but declares a stronger requirement
 dependency. Dependencies of this type may also be configured by adding a symlink to a
 C<.requires/> directory accompanying the unit file.
 
@@ -435,6 +441,23 @@ C<b.service>. C<ConsistsOf>
 dependency cannot be specified directly.",
         'type' => 'list'
       },
+      'Upholds',
+      {
+        'description' => 'Configures dependencies similar to C<Wants>, but as long a this unit
+is up, all units listed in C<Upholds> are started whenever found to be inactive or
+failed, and no job is queued for them. While a C<Wants> dependency on another unit
+has a one-time effect when this units started, a C<Upholds> dependency on it has a
+continuous effect, constantly restarting the unit if necessary. This is an alternative to the
+C<Restart> setting of service units, to ensure they are kept running whatever
+happens.
+
+When C<Upholds=b.service> is used on C<a.service>, this
+dependency will show as C<UpheldBy=a.service> in the property listing of
+C<b.service>. The C<UpheldBy> dependency cannot be specified
+directly.',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
       'Conflicts',
       {
         'cargo' => {
@@ -550,35 +573,52 @@ creates the corresponding device unit without delay.',
       },
       'OnFailure',
       {
-        'description' => 'A space-separated list of one or more units
-that are activated when this unit enters the
-C<failed> state.  A service unit using
-C<Restart> enters the failed state only after
-the start limits are reached.',
+        'description' => 'A space-separated list of one or more units that are activated when this unit enters
+the C<failed> state.  A service unit using C<Restart> enters the
+failed state only after the start limits are reached.',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'OnSuccess',
+      {
+        'description' => 'A space-separated list of one or more units that are activated when this unit enters
+the C<inactive> state.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'PropagatesReloadTo',
       {
-        'description' => 'A space-separated list of one or more units
-where reload requests on this unit will be propagated to, or
-reload requests on the other unit will be propagated to this
-unit, respectively. Issuing a reload request on a unit will
-automatically also enqueue a reload request on all units that
-the reload request shall be propagated to via these two
-settings.',
+        'description' => 'A space-separated list of one or more units to which reload requests from this unit
+shall be propagated to, or units from which reload requests shall be propagated to this unit,
+respectively. Issuing a reload request on a unit will automatically also enqueue reload requests on
+all units that are linked to it using these two settings.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'ReloadPropagatedFrom',
       {
-        'description' => 'A space-separated list of one or more units
-where reload requests on this unit will be propagated to, or
-reload requests on the other unit will be propagated to this
-unit, respectively. Issuing a reload request on a unit will
-automatically also enqueue a reload request on all units that
-the reload request shall be propagated to via these two
-settings.',
+        'description' => 'A space-separated list of one or more units to which reload requests from this unit
+shall be propagated to, or units from which reload requests shall be propagated to this unit,
+respectively. Issuing a reload request on a unit will automatically also enqueue reload requests on
+all units that are linked to it using these two settings.',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'PropagatesStopTo',
+      {
+        'description' => 'A space-separated list of one or more units to which stop requests from this unit
+shall be propagated to, or units from which stop requests shall be propagated to this unit,
+respectively. Issuing a stop request on a unit will automatically also enqueue stop requests on all
+units that are linked to it using these two settings.',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'StopPropagatedFrom',
+      {
+        'description' => 'A space-separated list of one or more units to which stop requests from this unit
+shall be propagated to, or units from which stop requests shall be propagated to this unit,
+respectively. Issuing a stop request on a unit will automatically also enqueue stop requests on all
+units that are linked to it using these two settings.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
@@ -586,14 +626,16 @@ settings.',
       {
         'description' => 'For units that start processes (such as service units), lists one or more other units
 whose network and/or temporary file namespace to join. This only applies to unit types which support
-the C<PrivateNetwork>, C<NetworkNamespacePath> and
+the C<PrivateNetwork>, C<NetworkNamespacePath>,
+C<PrivateIPC>, C<IPCNamespacePath>, and
 C<PrivateTmp> directives (see
 L<systemd.exec(5)> for
 details). If a unit that has this setting set is started, its processes will see the same
-C</tmp/>, C</var/tmp/> and network namespace as one listed unit
-that is started. If multiple listed units are already started, it is not defined which namespace is
-joined. Note that this setting only has an effect if
-C<PrivateNetwork>/C<NetworkNamespacePath> and/or
+C</tmp/>, C</var/tmp/>, IPC namespace and network namespace as
+one listed unit that is started. If multiple listed units are already started, it is not defined
+which namespace is joined. Note that this setting only has an effect if
+C<PrivateNetwork>/C<NetworkNamespacePath>,
+C<PrivateIPC>/C<IPCNamespacePath> and/or
 C<PrivateTmp> is enabled for both the unit that joins the namespace and the unit
 whose namespace is joined.',
         'type' => 'leaf',
@@ -793,55 +835,69 @@ request default behaviour.",
       },
       'JobTimeoutSec',
       {
-        'description' => 'When a job for this unit is queued, a timeout C<JobTimeoutSec> may be
-configured. Similarly, C<JobRunningTimeoutSec> starts counting when the queued job is actually
-started. If either time limit is reached, the job will be cancelled, the unit however will not change state or
-even enter the C<failed> mode. This value defaults to C<infinity> (job timeouts
-disabled), except for device units (C<JobRunningTimeoutSec> defaults to
-C<DefaultTimeoutStartSec>). NB: this timeout is independent from any unit-specific timeout
-(for example, the timeout set with C<TimeoutStartSec> in service units) as the job timeout has
-no effect on the unit itself, only on the job that might be pending for it. Or in other words: unit-specific
-timeouts are useful to abort unit state changes, and revert them. The job timeout set with this option however
-is useful to abort only the job waiting for the unit state to change.',
+        'description' => 'C<JobTimeoutSec> specifies a timeout for the whole job that starts
+running when the job is queued. C<JobRunningTimeoutSec> specifies a timeout that
+starts running when the queued job is actually started. If either limit is reached, the job will be
+cancelled, the unit however will not change state or even enter the C<failed> mode.
+
+Both settings take a time span with the default unit of seconds, but other units may be
+specified, see
+L<systemd.time(5)>.
+The default is C<infinity> (job timeouts disabled), except for device units where
+C<JobRunningTimeoutSec> defaults to C<DefaultTimeoutStartSec>.
+
+Note: these timeouts are independent from any unit-specific timeouts (for example, the timeout
+set with C<TimeoutStartSec> in service units). The job timeout has no effect on the
+unit itself. Or in other words: unit-specific timeouts are useful to abort unit state changes, and
+revert them. The job timeout set with this option however is useful to abort only the job waiting for
+the unit state to change.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'JobRunningTimeoutSec',
       {
-        'description' => 'When a job for this unit is queued, a timeout C<JobTimeoutSec> may be
-configured. Similarly, C<JobRunningTimeoutSec> starts counting when the queued job is actually
-started. If either time limit is reached, the job will be cancelled, the unit however will not change state or
-even enter the C<failed> mode. This value defaults to C<infinity> (job timeouts
-disabled), except for device units (C<JobRunningTimeoutSec> defaults to
-C<DefaultTimeoutStartSec>). NB: this timeout is independent from any unit-specific timeout
-(for example, the timeout set with C<TimeoutStartSec> in service units) as the job timeout has
-no effect on the unit itself, only on the job that might be pending for it. Or in other words: unit-specific
-timeouts are useful to abort unit state changes, and revert them. The job timeout set with this option however
-is useful to abort only the job waiting for the unit state to change.',
+        'description' => 'C<JobTimeoutSec> specifies a timeout for the whole job that starts
+running when the job is queued. C<JobRunningTimeoutSec> specifies a timeout that
+starts running when the queued job is actually started. If either limit is reached, the job will be
+cancelled, the unit however will not change state or even enter the C<failed> mode.
+
+Both settings take a time span with the default unit of seconds, but other units may be
+specified, see
+L<systemd.time(5)>.
+The default is C<infinity> (job timeouts disabled), except for device units where
+C<JobRunningTimeoutSec> defaults to C<DefaultTimeoutStartSec>.
+
+Note: these timeouts are independent from any unit-specific timeouts (for example, the timeout
+set with C<TimeoutStartSec> in service units). The job timeout has no effect on the
+unit itself. Or in other words: unit-specific timeouts are useful to abort unit state changes, and
+revert them. The job timeout set with this option however is useful to abort only the job waiting for
+the unit state to change.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'JobTimeoutAction',
       {
-        'description' => 'C<JobTimeoutAction> optionally configures an additional action to take when
-the timeout is hit, see description of C<JobTimeoutSec> and
+        'description' => 'C<JobTimeoutAction> optionally configures an additional action to
+take when the timeout is hit, see description of C<JobTimeoutSec> and
 C<JobRunningTimeoutSec> above. It takes the same values as
 C<StartLimitAction>. Defaults to C<none>.
-C<JobTimeoutRebootArgument> configures an optional reboot string to pass to the
-L<reboot(2)> system call.
-',
+
+C<JobTimeoutRebootArgument> configures an optional reboot string to pass to
+the L<reboot(2)> system
+call.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'JobTimeoutRebootArgument',
       {
-        'description' => 'C<JobTimeoutAction> optionally configures an additional action to take when
-the timeout is hit, see description of C<JobTimeoutSec> and
+        'description' => 'C<JobTimeoutAction> optionally configures an additional action to
+take when the timeout is hit, see description of C<JobTimeoutSec> and
 C<JobRunningTimeoutSec> above. It takes the same values as
 C<StartLimitAction>. Defaults to C<none>.
-C<JobTimeoutRebootArgument> configures an optional reboot string to pass to the
-L<reboot(2)> system call.
-',
+
+C<JobTimeoutRebootArgument> configures an optional reboot string to pass to
+the L<reboot(2)> system
+call.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
@@ -957,6 +1013,18 @@ system manager itself is compiled for. The test may be negated by prepending an
 mark.',
         'type' => 'list'
       },
+      'ConditionFirmware',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Check whether the system\'s firmware is of a certain type. Possible values are:
+C<uefi> (for systems with EFI),
+C<device-tree> (for systems with a device tree) and
+C<device-tree-compatible(xyz)> (for systems with a device tree that is compatible to C<xyz>).',
+        'type' => 'list'
+      },
       'ConditionVirtualization',
       {
         'cargo' => {
@@ -970,6 +1038,7 @@ C<vm> and
 C<container> to test against a generic type of virtualization solution, or one of
 C<qemu>,
 C<kvm>,
+C<amazon>,
 C<zvm>,
 C<vmware>,
 C<microsoft>,
@@ -1080,9 +1149,9 @@ check for variables passed in by the enclosing container manager or PAM.",
         'description' => 'C<ConditionSecurity> may be used to check whether the given
 security technology is enabled on the system. Currently, the recognized values are
 C<selinux>, C<apparmor>, C<tomoyo>,
-C<ima>, C<smack>, C<audit> and
-C<uefi-secureboot>. The test may be negated by prepending an exclamation
-mark.',
+C<ima>, C<smack>, C<audit>,
+C<uefi-secureboot> and C<tpm2>. The test may be negated by prepending
+an exclamation mark.',
         'type' => 'list'
       },
       'ConditionCapability',
@@ -1139,10 +1208,23 @@ update.
 
 If the C<systemd.condition-needs-update=> option is specified on the kernel
 command line (taking a boolean), it will override the result of this condition check, taking
-precedence over any file modification time checks. If it is used
+precedence over any file modification time checks. If the kernel command line option is used,
 C<systemd-update-done.service> will not have immediate effect on any following
 C<ConditionNeedsUpdate> checks, until the system is rebooted where the kernel
-command line option is not specified anymore.',
+command line option is not specified anymore.
+
+Note that to make this scheme effective, the timestamp of C</usr/> should
+be explicitly updated after its contents are modified. The kernel will automatically update
+modification timestamp on a directory only when immediate children of a directory are modified; an
+modification of nested files will not automatically result in mtime of C</usr/>
+being updated.
+
+Also note that if the update method includes a call to execute appropriate post-update steps
+itself, it should not touch the timestamp of C</usr/>. In a typical distribution
+packaging scheme, packages will do any required update steps as part of the installation or
+upgrade, to make package contents immediately usable. C<ConditionNeedsUpdate>
+should be used with other update mechanisms where such an immediate update does not
+happen.',
         'type' => 'list'
       },
       'ConditionFirstBoot',
@@ -1178,7 +1260,7 @@ precedence over C</etc/machine-id> existence checks.',
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
-        'description' => 'Check for the exists of a file. If the specified absolute path name does not exist,
+        'description' => 'Check for the existence of a file. If the specified absolute path name does not exist,
 the condition will fail. If the absolute path name passed to
 C<ConditionPathExists> is prefixed with an exclamation mark
 (C<!>), the test is negated, and the unit is only started if the path does not
@@ -1319,14 +1401,24 @@ C<@system>.',
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
-        'description' => 'Verify that the given cgroup controller (eg. C<cpu>) is available
-for use on the system. For example, a particular controller may not be available if it was disabled
-on the kernel command line with C<cgroup_disable=controller>. Multiple controllers
-may be passed with a space separating them; in this case the condition will only pass if all listed
-controllers are available for use. Controllers unknown to systemd are ignored. Valid controllers
-are C<cpu>, C<cpuacct>, C<io>,
-C<blkio>, C<memory>, C<devices>, and
-C<pids>.',
+        'description' => 'Check whether given cgroup controllers (e.g. C<cpu>) are available
+for use on the system or whether the legacy v1 cgroup or the modern v2 cgroup hierarchy is used.
+
+Multiple controllers may be passed with a space separating them; in this case the condition
+will only pass if all listed controllers are available for use. Controllers unknown to systemd are
+ignored. Valid controllers are C<cpu>, C<cpuacct>,
+C<io>, C<blkio>, C<memory>,
+C<devices>, and C<pids>. Even if available in the kernel, a
+particular controller may not be available if it was disabled on the kernel command line with
+C<cgroup_disable=controller>.
+
+Alternatively, two special strings C<v1> and C<v2> may be
+specified (without any controller names). C<v2> will pass if the unified v2 cgroup
+hierarchy is used, and C<v1> will pass if the legacy v1 hierarchy or the hybrid
+hierarchy are used (see the discussion of C<systemd.unified_cgroup_hierarchy> and
+C<systemd.legacy_systemd_cgroup_controller> in
+L<systemd.service(5)>
+for more information).',
         'type' => 'list'
       },
       'ConditionMemory',
@@ -1360,6 +1452,85 @@ differ. In particular, in containers the affinity mask usually matches the numbe
 to the container and not the physically available ones.',
         'type' => 'list'
       },
+      'ConditionCPUFeature',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Verify that a given CPU feature is available via the C<CPUID>
+instruction. This condition only does something on i386 and x86-64 processors. On other
+processors it is assumed that the CPU does not support the given feature. It checks the leaves
+C<1>, C<7>, C<0x80000001>, and
+C<0x80000007>. Valid values are:
+C<fpu>,
+C<vme>,
+C<de>,
+C<pse>,
+C<tsc>,
+C<msr>,
+C<pae>,
+C<mce>,
+C<cx8>,
+C<apic>,
+C<sep>,
+C<mtrr>,
+C<pge>,
+C<mca>,
+C<cmov>,
+C<pat>,
+C<pse36>,
+C<clflush>,
+C<mmx>,
+C<fxsr>,
+C<sse>,
+C<sse2>,
+C<ht>,
+C<pni>,
+C<pclmul>,
+C<monitor>,
+C<ssse3>,
+C<fma3>,
+C<cx16>,
+C<sse4_1>,
+C<sse4_2>,
+C<movbe>,
+C<popcnt>,
+C<aes>,
+C<xsave>,
+C<osxsave>,
+C<avx>,
+C<f16c>,
+C<rdrand>,
+C<bmi1>,
+C<avx2>,
+C<bmi2>,
+C<rdseed>,
+C<adx>,
+C<sha_ni>,
+C<syscall>,
+C<rdtscp>,
+C<lm>,
+C<lahf_lm>,
+C<abm>,
+C<constant_tsc>.',
+        'type' => 'list'
+      },
+      'ConditionOSRelease',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Verify that a specific C<key=value> pair is set in the host\'s
+L<os-release(5)>.
+
+Other than exact matching with C<=>, and C<!=>, relative
+comparisons are supported for versioned parameters (e.g. C<VERSION_ID>). The
+comparator can be one of C<<>, C<<=>, C<=>,
+C<!=>, C<>=> and C<>>.',
+        'type' => 'list'
+      },
       'AssertArchitecture',
       {
         'description' => "Similar to the C<ConditionArchitecture>,
@@ -1426,6 +1597,20 @@ loudly). Note that hitting a configured assertion does not cause the unit to ent
 C<failed> state (or in fact result in any state change of the unit), it affects
 only the job queued for it. Use assertion expressions for units that cannot operate when specific
 requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertEnvironment',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
 into.",
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1580,6 +1765,20 @@ loudly). Note that hitting a configured assertion does not cause the unit to ent
 C<failed> state (or in fact result in any state change of the unit), it affects
 only the job queued for it. Use assertion expressions for units that cannot operate when specific
 requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertPathIsEncrypted',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
 into.",
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1664,6 +1863,48 @@ loudly). Note that hitting a configured assertion does not cause the unit to ent
 C<failed> state (or in fact result in any state change of the unit), it affects
 only the job queued for it. Use assertion expressions for units that cannot operate when specific
 requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertMemory',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertCPUs',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertOSRelease',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
 into.",
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1683,7 +1924,7 @@ into.",
         'warn' => 'OnFailureIsolate is now OnFailureJobMode.'
       }
     ],
-    'generated_by' => 'parse-man.pl from systemd 247 doc',
+    'generated_by' => 'parse-man.pl from systemd 249 doc',
     'license' => 'LGPLv2.1+',
     'name' => 'Systemd::Section::Unit'
   }
